import { parseUserId } from './user-id';
import { getDbUrlForUser } from './get-db-url-for-user';

export const replicationDocument = (
  userFromId: string,
  userFromPassword: string,
  userToId: string,
  userToPassword: string,
  adminUser: string
) => {
  const userFrom = parseUserId(userFromId);
  const userTo = parseUserId(userToId);

  const document = {
    _id: `${userFromId}=>${userToId}`,
    user_ctx: {
      name: adminUser,
      roles: ['_admin', '_reader', '_writer'],
    },
    source: {
      url: getDbUrlForUser(userFrom),
      auth: {
        basic: {
          username: userFrom.username,
          password: userFromPassword,
        },
      },
    },
    target: {
      url: getDbUrlForUser(userTo),
      auth: {
        basic: {
          username: userTo.username,
          password: userToPassword,
        },
      },
    },
    selector: {
      to: {
        $elemMatch: {
          $eq: userToId,
        },
      },
    },
    create_target: false,
    continuous: true,
    owner: adminUser,
  };

  return document;
};
